<%= embed_file('support/edit_warning.txt') %>
require 'rubygems'
require 'spork'

Spork.prefork do
<%= embed_template('support/_rails_prefork.rb.erb', '  ') %>

<%= embed_file("support/capybara.rb", '  ') %>
end

Spork.each_run do
<%= embed_template('support/_rails_each_run.rb.erb', '  ') %>
end
